pub struct SimpleMessage {Show 14 fields
pub from_email: String,
pub from_name: String,
pub sender: Option<bool>,
pub recipients: Vec<NameAndEmail>,
pub to: Option<String>,
pub cc: Option<String>,
pub bcc: Option<String>,
pub subject: Option<String>,
pub text_part: Option<String>,
pub html_part: Option<String>,
pub attachments: Option<Vec<Attachment>>,
pub inline_attachments: Option<Vec<Attachment>>,
pub event_payload: Option<String>,
pub vars: Option<String>,
}Expand description
Object that represents the parameters needed to send a message using the API::v3.0.
Description
This object matches the allowed parameters defined in /send.
However, some parameters are missing in this struct. Mostly, all the parameters that start by Mj- are
skipped due to problems with the request.
Fields
from_email: Stringfrom_name: Stringsender: Option<bool>recipients: Vec<NameAndEmail>to: Option<String>cc: Option<String>bcc: Option<String>subject: Option<String>text_part: Option<String>html_part: Option<String>attachments: Option<Vec<Attachment>>inline_attachments: Option<Vec<Attachment>>event_payload: Option<String>vars: Option<String>Trait Implementations
Sourceimpl Clone for SimpleMessage
impl Clone for SimpleMessage
Sourcefn clone(&self) -> SimpleMessage
fn clone(&self) -> SimpleMessage
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SimpleMessage
impl Debug for SimpleMessage
Sourceimpl Default for SimpleMessage
impl Default for SimpleMessage
Sourcefn default() -> SimpleMessage
fn default() -> SimpleMessage
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for SimpleMessage
impl<'de> Deserialize<'de> for SimpleMessage
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl RequestObject for SimpleMessage
impl RequestObject for SimpleMessage